@@ -138,6 +138,7 @@ class TheOneRingConnection(
 			autogv.NewGVConversations(weakref.ref(self)),
 			autogv.RefreshVoicemail(weakref.ref(self)),
 			autogv.AutoDisconnect(weakref.ref(self)),
+			autogv.DelayEnableContactIntegration(constants._telepathy_implementation_name_),
 		]
 		self._delayedConnect = gobject_utils.Async(self._delayed_connect)
 
@@ -301,4 +302,9 @@ class TheOneRingConnection(
 		self.session.logout()
 		self.session.close()
 
+		# In case one of the above items takes too long (which it should never
+		# do), we leave the starting of the shutdown-on-idle counter to the
+		# very end
+		self.manager.disconnect_completed()
+
 		_moduleLogger.info("Disconnected")
